Adds a footer row to the global TFL options, which can be used as defaults for all spec objects.
Usage
# S3 method for class 'TFL_options'
add_footer(spec, ..., level = NULL)Adds a footer row to the global TFL options, which can be used as defaults for all spec objects.
# S3 method for class 'TFL_options'
add_footer(spec, ..., level = NULL)