Skip to contents

Prints the font resolution report from the most recent scan without re-scanning. Use tfl_rescan_fonts() to perform a fresh scan.

Usage

tfl_font_status()

Value

Invisibly returns the cached font scan report.

See also

tfl_rescan_fonts() to re-run the scan.

Examples

# Check which fonts are resolved and which use fallbacks
tfl_font_status()
#> ksTFL font scan: 0 target(s) resolved, 6 using fallback
#>   [fallback] Arial                -> Liberation Sans
#>   [fallback] Times New Roman      -> Liberation Serif
#>   [fallback] Courier New          -> Liberation Mono
#>   [fallback] Georgia              -> Liberation Serif
#>   [fallback] Verdana              -> Liberation Sans
#>   [fallback] Trebuchet MS         -> Liberation Sans
#>   Scanned 12 directories