When adding body text to a spec that has default body text entries (IDs starting with _default), they are automatically removed to avoid mixing defaults with user-defined content.
Usage
# S3 method for class 'TFL_spec'
add_body_text(spec, text = NULL, id = NULL, styleRef = NULL, order = NULL)Arguments
- spec
TFL_spec object
- text
Character vector of body text lines
- id
Body text identifier (auto-generated if NULL)
- styleRef
Character vector of style names or result of
f_combine(). Merged with last-win strategy.- order
Order of body text group (auto-assigned if NULL)