Used inside compute_cols() to signal the renderer to start a new page
at every row matching the condition. Takes no arguments.
Value
Action marker (internal use within compute_cols())
Examples
if (FALSE) { # \dontrun{
data <- data.frame(
group = c("A", "A", "B", "B", "C"),
value = c(1, 2, 3, 4, 5)
)
# Force a new page at the start of each group
spec <- create_table(data) |>
compute_cols(firstOf(group), c_pageBreak())
} # }