Skip to contents

Prints the font resolution report from the most recent scan without re-scanning. Use tfl_rescan_fonts() to perform a fresh scan.

Usage

tfl_font_status()

Value

Invisibly returns the cached font scan report.

See also

tfl_rescan_fonts() to re-run the scan.

Examples

if (FALSE) { # \dontrun{
# Check which fonts are resolved and which use fallbacks
tfl_font_status()
} # }