Prints the font resolution report from the most recent scan without
re-scanning. Use tfl_rescan_fonts() to perform a fresh scan.
See also
tfl_rescan_fonts() to re-run the scan.
Prints the font resolution report from the most recent scan without
re-scanning. Use tfl_rescan_fonts() to perform a fresh scan.
tfl_rescan_fonts() to re-run the scan.